==> gcc-4.4.5.tar.bz2: gcc-4.4.5/libstdc++-v3/testsuite/19_diagnostics/error_condition/modifiers/39881.cc <==
// { dg-options "-std=gnu++0x" }

// Copyright (C) 2009 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <system_error>
#include <testsuite_hooks.h>

enum my_errc { my_err = 0 };

class my_error_category_impl
: public std::error_category
{
public:
  const char* name() const { return ""; }
  std::string message(int) const { return ""; }
} my_error_category_instance;

std::error_condition
make_error_condition(my_errc e)
{
  return std::error_condition(static_cast<int>(e),
			      my_error_category_instance);
}

namespace std
{
  template<>
    struct is_error_condition_enum<my_errc>
    : public true_type { };
}

// libstdc++/39881
void test01()
{
  bool test __attribute__((unused)) = true;

  std::error_condition ec2;
  ec2 = my_err;
  VERIFY( ec2 == make_error_condition(my_err) );
}

int main()
{
  test01();
  return 0;
}

==> gcc-4.7.4.tar.bz2: gcc-4.7.4/libstdc++-v3/testsuite/19_diagnostics/error_condition/modifiers/39881.cc <==
// { dg-options "-std=gnu++0x" }

// Copyright (C) 2009, 2010, 2011 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.

#include <system_error>
#include <testsuite_hooks.h>

enum my_errc { my_err = 0 };

class my_error_category_impl
: public std::error_category
{
public:
  const char* name() const noexcept { return ""; }
  std::string message(int) const { return ""; }
} my_error_category_instance;

std::error_condition
make_error_condition(my_errc e)
{
  return std::error_condition(static_cast<int>(e),
			      my_error_category_instance);
}

namespace std
{
  template<>
    struct is_error_condition_enum<my_errc>
    : public true_type { };
}

// libstdc++/39881
void test01()
{
  bool test __attribute__((unused)) = true;

  std::error_condition ec2;
  ec2 = my_err;
  VERIFY( ec2 == make_error_condition(my_err) );
}

int main()
{
  test01();
  return 0;
}
